@@ -13,9 +13,10 @@ typedef fz::http::client::request_response_holder<fz::http::client::request, fz:
 class client : public fz::event_handler, public fz::http::client::client
 {
 public:
-	client(std::vector<fz::uri> uris, fz::event_loop & loop, fz::aio_buffer_pool & buffer_pool, fz::logger_interface & logger)
+	client(std::vector<fz::uri> const& uris, fz::thread_pool & tpool, fz::event_loop & loop, fz::aio_buffer_pool & buffer_pool, fz::logger_interface & logger)
 		: fz::event_handler(loop)
 		, fz::http::client::client(*this, buffer_pool, logger, "libfilezilla_https_demo")
+		, pool_(tpool)
 		, logger_(logger)
 		, trust_store_(pool_)
 	{
@@ -79,7 +80,7 @@ public:
 		}
 	}
 
-	fz::thread_pool pool_;
+	fz::thread_pool & pool_;
 	fz::logger_interface & logger_;
 	fz::tls_system_trust_store trust_store_;
 
@@ -111,8 +112,9 @@ int main(int argc , char * argv[])
 	//logger.set_all(fz::logmsg::type(-1));
 
 	// Create a handler
-	fz::aio_buffer_pool buffer_pool(logger, 8);
-	client c(uris, loop, buffer_pool, logger);
+	fz::thread_pool tpool;
+	fz::aio_buffer_pool buffer_pool(tpool, logger, 8);
+	client c(uris, tpool, loop, buffer_pool, logger);
 
 	loop.run();
 
