@@ -73,11 +73,11 @@ void event_loop::remove_handler(event_handler* handler)
 	scoped_lock l(sync_);
 
 	auto is_part_of_group = [&](event_handler* h, event_handler* group) {
-		while (group) {
+		while (h) {
 			if (h == group) {
 				return true;
 			}
-			group = group->parent_;
+			h = h->parent_;
 		}
 		return false;
 	};
