@@ -13,6 +13,14 @@
 
 namespace fz {
 
+enum class uri_parsing_flags
+{
+	normal,
+
+	/// If parsing a schemeless URI, assume it has an authority, otherwise it's all seen as path
+	assume_authority
+};
+
 /**
  * \brief The uri class is used to decompose URIs into their individual components.
  *
@@ -22,7 +30,7 @@ class FZ_PUBLIC_SYMBOL uri final
 {
 public:
 	uri() noexcept = default;
-	explicit uri(std::string_view const& in);
+	explicit uri(std::string_view const& in, uri_parsing_flags flags = {});
 
 	void clear();
 
@@ -32,7 +40,7 @@ public:
 	 * Percent-decodes username, pass, host and path
 	 * Does not decode query and fragment.
 	 **/
-	bool parse(std::string_view in);
+	bool parse(std::string_view in, uri_parsing_flags flags = {});
 
 	/**
 	 * \brief Assembles components into string
